NewsFeedEntry class

This class is the equivalent of a news feed entry.

Constructors

NewsFeedEntry(Map<String, String?> entry)

Properties

body → String
no setter
campaignType → NewsFeedCampaignType
no setter
deliveredAt → DateTime?
This property is a UTC date.
no setter
deviceID → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setter
imageUrl → String?
no setter
imageUrlString → String?
no setter
linkUrl → String?
no setter
linkUrlString → String?
no setter
rawDeliveredAt → String?
no setter
read ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shown ↔ bool
getter/setter pair
summary → String
no setter
title → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited